@@ -1,11 +1,11 @@
 import getpass
-yLbSE=object
-yLbSe=staticmethod
-yLbSG=False
-yLbSo=Exception
-yLbSK=None
-yLbSw=input
-yLbSr=list
+QRaAr=object
+QRaAb=staticmethod
+QRaAH=False
+QRaAK=Exception
+QRaAz=None
+QRaAT=input
+QRaAp=list
 import json
 import logging
 import sys
@@ -13,29 +13,29 @@ from localstack.config import CONFIG_FILE_PATH,load_config_file
 from localstack.constants import API_ENDPOINT
 from localstack.utils.common import load_file,safe_requests,save_file,to_str
 LOG=logging.getLogger(__name__)
-class AuthProvider(yLbSE):
- @yLbSe
+class AuthProvider(QRaAr):
+ @QRaAb
  def name():
   raise
  def get_or_create_token(self,username,password,headers):
   pass
  def get_user_for_token(self,token):
   pass
- @yLbSe
+ @QRaAb
  def providers():
   return{c.name():c for c in AuthProvider.__subclasses__()}
- @yLbSe
- def get(provider,raise_error=yLbSG):
+ @QRaAb
+ def get(provider,raise_error=QRaAH):
   provider_class=AuthProvider.providers().get(provider)
   if not provider_class:
    msg='Unable to find auth provider class "%s"'%provider
    LOG.warning(msg)
    if raise_error:
-    raise yLbSo(msg)
-   return yLbSK
+    raise QRaAK(msg)
+   return QRaAz
   return provider_class()
 class AuthProviderInternal(AuthProvider):
- @yLbSe
+ @QRaAb
  def name():
   return "internal"
  def get_or_create_token(self,username,password,headers):
@@ -46,28 +46,28 @@ class AuthProviderInternal(AuthProvider):
   try:
    result=json.loads(to_str(response.content or "{}"))
    return result["token"]
-  except yLbSo:
+  except QRaAK:
    pass
  def read_credentials(self,username):
   print("Please provide your login credentials below")
   if not username:
    sys.stdout.write("Username: ")
    sys.stdout.flush()
-   username=yLbSw()
+   username=QRaAT()
   password=getpass.getpass()
   return username,password,{}
  def get_user_for_token(self,token):
-  raise yLbSo("Not implemented")
-def login(provider,username=yLbSK):
+  raise QRaAK("Not implemented")
+def login(provider,username=QRaAz):
  auth_provider=AuthProvider.get(provider)
  if not auth_provider:
-  providers=yLbSr(AuthProvider.providers().keys())
-  raise yLbSo('Unknown provider "%s", should be one of %s'%(provider,providers))
+  providers=QRaAp(AuthProvider.providers().keys())
+  raise QRaAK('Unknown provider "%s", should be one of %s'%(provider,providers))
  username,password,headers=auth_provider.read_credentials(username)
  print("Verifying credentials ... (this may take a few moments)")
  token=auth_provider.get_or_create_token(username,password,headers)
  if not token:
-  raise yLbSo("Unable to verify login credentials - please try again")
+  raise QRaAK("Unable to verify login credentials - please try again")
  configs=load_config_file()
  configs["login"]={"provider":provider,"username":username,"token":token}
  save_file(CONFIG_FILE_PATH,json.dumps(configs))
