@@ -1,10 +1,10 @@
 import glob
-hinPw=True
-hinPs=dict
-hinPF=open
-hinPJ=False
-hinPm=Exception
-hinPo=int
+IetWU=True
+IetWq=dict
+IetWs=open
+IetWG=False
+IetWw=Exception
+IetWX=int
 import json
 import logging
 import os
@@ -25,14 +25,14 @@ ROOT_USER=("root","pass123")
 FTP_USER_DEFAULT_PASSWD="12345"
 FTP_USER_PERMISSIONS="elradfmwMT"
 FTP_PASSIVE_PORTS=[ext_config.SERVICE_INSTANCES_PORTS_END-2,ext_config.SERVICE_INSTANCES_PORTS_END-1,ext_config.SERVICE_INSTANCES_PORTS_END]
-USE_SUBPROCESS=hinPw
+USE_SUBPROCESS=IetWU
 DIRECTORY_MAPPING={}
 DIRECTORY_MAPPING_FILE="<data_dir>/ftp.user.dir.mapping.json"
 def get_dir_mapping_key(username,server_port):
  return "{}:{}".format(username,server_port)
 def apply_patches():
  extended_proto_cmds=TLS_FTPHandler.proto_cmds.copy()
- extended_proto_cmds.update({"SITE ADDUSER":hinPs(perm="m",auth=hinPw,arg=hinPw,help="Syntax: SITE <SP> ADDUSER USERNAME PASSWORD HOME PRIVS <SP>.")})
+ extended_proto_cmds.update({"SITE ADDUSER":IetWq(perm="m",auth=IetWU,arg=IetWU,help="Syntax: SITE <SP> ADDUSER USERNAME PASSWORD HOME PRIVS <SP>.")})
  def _on_file_received(self,file_path):
   key=get_dir_mapping_key(self.username,self.server.address[1])
   mapping=get_directory_mapping()
@@ -42,7 +42,7 @@ def apply_patches():
   bucket=configuration["HomeDirectory"]
   user_dir=configuration["UserDirectory"]
   key=file_path.replace("{}/".format(user_dir),"")
-  with hinPF(file_path)as f:
+  with IetWs(file_path)as f:
    s3_client=aws_stack.connect_to_service("s3")
    s3_client.put_object(Bucket=bucket,Key=key,Body=f.read())
    LOG.info("Received file via FTP -- target: s3://{}/{}".format(bucket,key))
@@ -83,16 +83,16 @@ def start_ftp(port):
    pythonpath+=":%s"%":".join(paths)
   env_vars={"SERVICES":services,"PYTHONPATH":pythonpath}
   cmd="%s %s %s"%(sys.executable,__file__,port)
-  thread=ShellCommandThread(cmd,outfile=subprocess.PIPE,env_vars=env_vars,quiet=hinPJ)
+  thread=ShellCommandThread(cmd,outfile=subprocess.PIPE,env_vars=env_vars,quiet=IetWG)
   thread.start()
   time.sleep(2)
  else:
-  thread=do_start_ftp(port,asynchronous=hinPw)
+  thread=do_start_ftp(port,asynchronous=IetWU)
  time.sleep(2)
  wait_for_port_open(port,retries=10,sleep_time=1.5)
  TMP_THREADS.append(thread)
  return thread
-def do_start_ftp(port,asynchronous=hinPw):
+def do_start_ftp(port,asynchronous=IetWU):
  LOG.info("Starting (S)FTP server on port %s..."%port)
  apply_patches()
  authorizer=DummyAuthorizer()
@@ -110,7 +110,7 @@ def do_start_ftp(port,asynchronous=hinPw):
   try:
    server=FTPServer(("0.0.0.0",port),handler)
    server.serve_forever()
-  except hinPm as e:
+  except IetWw as e:
    LOG.info("Unable to run FTP server on port %s: %s"%(port,e))
    raise
  if asynchronous:
@@ -134,7 +134,7 @@ def set_directory_mapping(key,value):
 def get_directory_mapping_file():
  return DIRECTORY_MAPPING_FILE.replace("<data_dir>",localstack_config.TMP_FOLDER)
 def main():
- do_start_ftp(hinPo(sys.argv[1]),asynchronous=hinPJ)
+ do_start_ftp(IetWX(sys.argv[1]),asynchronous=IetWG)
 if __name__=="__main__":
  main()
 # Created by pyminifier (https://github.com/liftoff/pyminifier)
