@@ -1,15 +1,15 @@
 #!/usr/bin/env python
-CRrep=None
-CRreU=True
-CRreO=Exception
-CRreB=str
-CRrex=len
-CRrec=isinstance
-CRreV=dict
-CRreq=hasattr
-CRreT=int
-CRreb=False
-CRref=bytes
+AIKBq=None
+AIKBv=True
+AIKBJ=Exception
+AIKBD=str
+AIKBh=len
+AIKBS=isinstance
+AIKBG=dict
+AIKBE=hasattr
+AIKBn=int
+AIKBY=False
+AIKBr=bytes
 import json
 import logging
 import os
@@ -38,32 +38,32 @@ USED_BIND_ADDRESSES=[]
 MAC_NETWORK_INTERFACE="en0"
 BUCKET_MARKER_LOCAL=(os.environ.get("BUCKET_MARKER_LOCAL")or "").strip()or "__local__"
 class FuncThread(threading.Thread):
- def __init__(self,func,params=CRrep):
+ def __init__(self,func,params=AIKBq):
   threading.Thread.__init__(self)
-  self.daemon=CRreU
+  self.daemon=AIKBv
   self.params=params
   self.func=func
  def run(self):
   try:
    self.func(self.params)
-  except CRreO as e:
+  except AIKBJ as e:
    log("Error in thread function: %s %s"%(e,traceback.format_exc()))
 class ThreadedHTTPServer(ThreadingMixIn,HTTPServer):
- daemon_threads=CRreU
+ daemon_threads=AIKBv
 class RequestHandler(BaseHTTPRequestHandler):
  def do_POST(self):
   self.read_content()
   try:
    result=self.handle_request()
    self.send_response(200)
-  except CRreO as e:
-   error_string=CRreB(e)
+  except AIKBJ as e:
+   error_string=AIKBD(e)
    result=json.dumps({"error":error_string})
    log("Error handling request: %s - %s"%(self.request_json,e))
    self.send_response(500)
-  self.send_header("Content-Length","%s"%CRrex(result)if result else 0)
+  self.send_header("Content-Length","%s"%AIKBh(result)if result else 0)
   self.end_headers()
-  if CRrex(result or ""):
+  if AIKBh(result or ""):
    self.wfile.write(to_bytes(result))
  def handle_request(self):
   request=self.request_json
@@ -83,17 +83,17 @@ class RequestHandler(BaseHTTPRequestHandler):
    os._exit(0)
   else:
    result={"error":'Unsupported operation "%s"'%operation}
-  result=json.dumps(result)if CRrec(result,CRreV)else result
+  result=json.dumps(result)if AIKBS(result,AIKBG)else result
   return result
  def read_content(self):
-  if CRreq(self,"data_bytes"):
+  if AIKBE(self,"data_bytes"):
    return
   content_length=self.headers.get("Content-Length")
-  self.data_bytes=self.rfile.read(CRreT(content_length))
+  self.data_bytes=self.rfile.read(AIKBn(content_length))
   self.request_json={}
   try:
    self.request_json=json.loads(self.data_bytes)
-  except CRreO:
+  except AIKBJ:
    pass
 class RequestHandlerRoot(RequestHandler):
  def handle_request(self):
@@ -107,13 +107,13 @@ class RequestHandlerRoot(RequestHandler):
    os._exit(0)
   else:
    result={"error":'Unsupported operation "%s"'%operation}
-  result=json.dumps(result)if CRrec(result,CRreV)else result
+  result=json.dumps(result)if AIKBS(result,AIKBG)else result
   return result
 def s3_download(request):
  bucket=request["bucket"]
  key=request["key"]
  tmp_dir=os.environ.get("TMPDIR")or tempfile.mkdtemp()
- target_file=os.path.join(tmp_dir,request.get("file_name")or "s3file.%s"%CRreB(uuid.uuid4()))
+ target_file=os.path.join(tmp_dir,request.get("file_name")or "s3file.%s"%AIKBD(uuid.uuid4()))
  if not os.path.exists(target_file)or request.get("overwrite"):
   if bucket==BUCKET_MARKER_LOCAL:
    shutil.copy(key,target_file)
@@ -132,14 +132,14 @@ def start_ssh_forward_proxy(options):
   sys.path.append(path)
  from tcp_proxy import server_loop
  port=options.get("port")or get_free_tcp_port()
- host=LOCAL_BIND_ADDRESS_PATTERN.replace("*",CRreB(CRrex(USED_BIND_ADDRESSES)+2))
+ host=LOCAL_BIND_ADDRESS_PATTERN.replace("*",AIKBD(AIKBh(USED_BIND_ADDRESSES)+2))
  create_network_interface_alias(host)
  USED_BIND_ADDRESSES.append(host)
  log("Starting local SSH forward proxy, %s:22 -> localhost:%s"%(host,port))
  options={"bind_port":22,"bind_addr":host,"port":port}
  FuncThread(server_loop,options).start()
  return{"host":host,"forward_port":port}
-def create_network_interface_alias(address,interface=CRrep):
+def create_network_interface_alias(address,interface=AIKBq):
  sudo_cmd="sudo"
  if is_mac_os():
   interface=interface or MAC_NETWORK_INTERFACE
@@ -156,16 +156,16 @@ def create_network_interface_alias(address,interface=CRrep):
     assert interface not in["lo"]and not iface_addr.startswith("127.")
     run_cmd("{sudo_cmd} ifconfig {iface}:0 {addr} netmask 255.255.255.0 up".format(sudo_cmd=sudo_cmd,addr=address,iface=interface))
     return
-   except CRreO as e:
+   except AIKBJ as e:
     log("Unable to create forward proxy on interface %s, address %s: %s"%(interface,address,e))
     pass
- raise CRreO("Unable to create network interface")
+ raise AIKBJ("Unable to create network interface")
 def run_shell_cmd(command):
  try:
   return{"result":run_cmd(command)}
- except CRreO as e:
-  error_string=CRreB(e)
-  if CRrec(e,subprocess.CalledProcessError):
+ except AIKBJ as e:
+  error_string=AIKBD(e)
+  if AIKBS(e,subprocess.CalledProcessError):
    error_string="%s: %s"%(error_string,e.output)
   return{"error":error_string}
 def get_os():
@@ -176,22 +176,22 @@ def get_os():
  return "windows"
 def run_cmd(cmd):
  log("Running command: %s"%cmd)
- return to_str(subprocess.check_output(cmd,stderr=subprocess.STDOUT,shell=CRreU))
+ return to_str(subprocess.check_output(cmd,stderr=subprocess.STDOUT,shell=AIKBv))
 def log(*args):
  print(*args)
  sys.stdout.flush()
 def is_mac_os():
  try:
-  out=to_str(subprocess.check_output("uname -a",shell=CRreU))
+  out=to_str(subprocess.check_output("uname -a",shell=AIKBv))
   return "Darwin" in out
  except subprocess.CalledProcessError:
-  return CRreb
+  return AIKBY
 def is_linux():
  try:
-  out=to_str(subprocess.check_output("uname -a",shell=CRreU))
+  out=to_str(subprocess.check_output("uname -a",shell=AIKBv))
   return "Linux" in out
  except subprocess.CalledProcessError:
-  return CRreb
+  return AIKBY
 def get_ip_address(ifname):
  import fcntl
  s=socket.socket(socket.AF_INET,socket.SOCK_DGRAM)
@@ -203,29 +203,29 @@ def get_free_tcp_port():
  tcp.close()
  return port
 def to_bytes(obj):
- return obj.encode("utf-8")if CRrec(obj,CRreB)else obj
+ return obj.encode("utf-8")if AIKBS(obj,AIKBD)else obj
 def to_str(obj):
- return obj.decode("utf-8")if CRrec(obj,CRref)else obj
+ return obj.decode("utf-8")if AIKBS(obj,AIKBr)else obj
 def start_server(port,handler):
  kill_server(port)
  try:
   log("Starting local daemon server on port %s"%port)
   httpd=ThreadedHTTPServer(("0.0.0.0",port),handler)
   httpd.serve_forever()
- except CRreO:
+ except AIKBJ:
   log("Local daemon server already running, or port %s not available"%port)
   pass
 def kill_server(port):
  try:
   requests.post("http://localhost:%s"%port,data='{"op":"kill"}')
- except CRreO:
+ except AIKBJ:
   pass
 def kill_servers():
  kill_server(DEFAULT_PORT_LOCAL_DAEMON)
  kill_server(DEFAULT_PORT_LOCAL_DAEMON_ROOT)
 def main():
  logging.basicConfig()
- daemon_type=sys.argv[1]if CRrex(sys.argv)>1 else "main"
+ daemon_type=sys.argv[1]if AIKBh(sys.argv)>1 else "main"
  os.environ["AWS_ACCESS_KEY_ID"]=os.environ.get("AWS_ACCESS_KEY_ID")or "test"
  os.environ["AWS_SECRET_ACCESS_KEY"]=os.environ.get("AWS_SECRET_ACCESS_KEY")or "test"
  if daemon_type=="main":
@@ -241,12 +241,12 @@ def start_in_background():
  LOG.info("Logging local daemon output to %s"%log_file)
  python_cmd=sys.executable
  cmd="%s %s"%(python_cmd,__file__)
- run(cmd,outfile=log_file,asynchronous=CRreU)
+ run(cmd,outfile=log_file,asynchronous=AIKBv)
  LOG.info("Attempting to obtain sudo privileges for local daemon of EC2 API "+"(required to start SSH forward proxy on privileged port 22). "+"You may be asked for your sudo password.")
- run("sudo ls",stdin=CRreU)
+ run("sudo ls",stdin=AIKBv)
  def start_root_daemon(*args):
   cmd="sudo %s %s root >> %s"%(python_cmd,__file__,log_file)
-  run(cmd,outfile=log_file,stdin=CRreU)
+  run(cmd,outfile=log_file,stdin=AIKBv)
  FuncThread(start_root_daemon).start()
 if __name__=="__main__":
  main()
