@@ -1,17 +1,17 @@
 import json
-DlNGp=object
-DlNGM=None
-DlNGd=Exception
-DlNGP=set
-DlNGC=property
-DlNGY=classmethod
-DlNGu=True
-DlNGF=len
-DlNGI=getattr
-DlNGo=type
-DlNGm=isinstance
-DlNGv=list
-DlNGJ=False
+SMJmx=object
+SMJmg=None
+SMJmb=Exception
+SMJmW=set
+SMJmK=property
+SMJmn=classmethod
+SMJmd=True
+SMJmU=len
+SMJmQ=getattr
+SMJmy=type
+SMJmj=isinstance
+SMJma=list
+SMJmf=False
 import logging
 import os
 import re
@@ -27,17 +27,17 @@ from localstack.utils.testutil import create_zip_file
 from localstack_ext.bootstrap.licensing import get_auth_headers
 LOG=logging.getLogger(__name__)
 PERSISTED_FOLDERS=["api_states","dynamodb","kinesis"]
-class CloudPodManager(DlNGp):
+class CloudPodManager(SMJmx):
  BACKEND="_none_"
- def __init__(self,pod_name=DlNGM,config=DlNGM):
+ def __init__(self,pod_name=SMJmg,config=SMJmg):
   self.pod_name=pod_name
   self._pod_config=config
  def push(self):
-  raise DlNGd("Not implemented")
+  raise SMJmb("Not implemented")
  def pull(self):
-  raise DlNGd("Not implemented")
+  raise SMJmb("Not implemented")
  def get_pod_size(self):
-  raise DlNGd("Not implemented")
+  raise SMJmb("Not implemented")
  def restart_container(self):
   LOG.info("Restarting LocalStack instance with updated persistence state - this may take some time ...")
   data={"action":"restart"}
@@ -51,20 +51,20 @@ class CloudPodManager(DlNGp):
    response=requests.get(url)
    content=json.loads(to_str(response.content))
    statuses=[v for k,v in content["services"].items()]
-   assert DlNGP(statuses)==DlNGP(["running"])
+   assert SMJmW(statuses)==SMJmW(["running"])
   retry(check_status,sleep=3,retries=10)
- @DlNGC
+ @SMJmK
  def pod_config(self):
   return self._pod_config or PodConfigManager.pod_config(self.pod_name)
- @DlNGY
+ @SMJmn
  def get(cls,pod_name):
   pod_config=PodConfigManager.pod_config(pod_name)
   backend=pod_config.get("backend")
   for clazz in cls.__subclasses__():
    if clazz.BACKEND==backend:
     return clazz(pod_name=pod_name,config=pod_config)
-  raise DlNGd('Unable to find Cloud Pod manager implementation type "%s"'%backend)
- @DlNGY
+  raise SMJmb('Unable to find Cloud Pod manager implementation type "%s"'%backend)
+ @SMJmn
  def data_dir(cls):
   if not config.DATA_DIR:
    try:
@@ -76,10 +76,10 @@ class CloudPodManager(DlNGp):
     data_dir_host=[m for m in mounts if m["Destination"]==data_dir_env][0]["Source"]
     data_dir_host=re.sub(r"^(/host_mnt)?",r"",data_dir_host)
     config.DATA_DIR=data_dir_host
-   except DlNGd:
+   except SMJmb:
     LOG.warning('''Unable to determine DATA_DIR from LocalStack Docker container - please make sure $MAIN_CONTAINER_NAME is configured properly''')
   if not config.DATA_DIR:
-   raise DlNGd("Working with local cloud pods requires $DATA_DIR configuration")
+   raise SMJmb("Working with local cloud pods requires $DATA_DIR configuration")
   return config.DATA_DIR
 class CloudPodManagerFilesystem(CloudPodManager):
  BACKEND="file"
@@ -112,11 +112,11 @@ class CloudPodManagerManaged(CloudPodManager):
  def push(self):
   presigned_url=self.presigned_url("push")
   data_dir=self.data_dir()
-  zip_data_content=create_zip_file(data_dir,get_content=DlNGu)
-  print('Pushing state of cloud pod "%s" to backend server (%s KB)'%(self.pod_name,format_number(DlNGF(zip_data_content)/1000.0)))
+  zip_data_content=create_zip_file(data_dir,get_content=SMJmd)
+  print('Pushing state of cloud pod "%s" to backend server (%s KB)'%(self.pod_name,format_number(SMJmU(zip_data_content)/1000.0)))
   res=safe_requests.put(presigned_url,data=zip_data_content)
   if res.status_code>=400:
-   raise DlNGd("Unable to push pod state to API (code %s): %s"%(res.status_code,res.content))
+   raise SMJmb("Unable to push pod state to API (code %s): %s"%(res.status_code,res.content))
   print("Done.")
  def pull(self):
   data_dir=self.data_dir()
@@ -136,7 +136,7 @@ class CloudPodManagerManaged(CloudPodManager):
   response=safe_requests.post("%s/cloudpods/data"%API_ENDPOINT,data,headers=auth_headers)
   content=response.content
   if response.status_code>=400:
-   raise DlNGd("Unable to push cloud pod to API (code %s): %s"%(response.status_code,content))
+   raise SMJmb("Unable to push cloud pod to API (code %s): %s"%(response.status_code,content))
   content=json.loads(to_str(content))
   return content["presignedURL"]
  def get_pod_size(self):
@@ -151,9 +151,9 @@ class CloudPodManagerGit(CloudPodManager):
   remote_location=self.pod_config.get("url")
   try:
    porcelain.pull(repo,remote_location,refspecs=branch)
-  except DlNGd as e:
+  except SMJmb as e:
    LOG.info("Unable to pull repo: %s"%e)
-  is_empty_repo=b"HEAD" not in repo or repo.refs.allkeys()==DlNGP([b"HEAD"])
+  is_empty_repo=b"HEAD" not in repo or repo.refs.allkeys()==SMJmW([b"HEAD"])
   if is_empty_repo:
    LOG.debug("Initializing empty repository %s"%self.clone_dir)
    init_file=os.path.join(self.clone_dir,".init")
@@ -161,7 +161,7 @@ class CloudPodManagerGit(CloudPodManager):
    porcelain.add(repo,init_file)
    porcelain.commit(repo,message="Initial commit")
   if branch not in repo:
-   porcelain.branch_create(repo,branch,force=DlNGu)
+   porcelain.branch_create(repo,branch,force=SMJmd)
   self.switch_branch(branch)
   for folder in PERSISTED_FOLDERS:
    LOG.info("Copying persistence folder %s to local git repo %s"%(folder,self.clone_dir))
@@ -182,7 +182,7 @@ class CloudPodManagerGit(CloudPodManager):
   branch=self.pod_config.get("branch")
   remote_ref=b"refs/heads/%s"%to_bytes(branch)
   if remote_ref not in remote_refs:
-   raise DlNGd('Unable to find branch "%s" in remote git repo'%branch)
+   raise SMJmb('Unable to find branch "%s" in remote git repo'%branch)
   remote_location=self.pod_config.get("url")
   self.switch_branch(branch)
   branch_ref=b"refs/heads/%s"%to_bytes(branch)
@@ -194,13 +194,13 @@ class CloudPodManagerGit(CloudPodManager):
   for folder in PERSISTED_FOLDERS:
    src_folder=os.path.join(self.clone_dir,folder)
    tgt_folder=os.path.join(self.data_dir(),folder)
-   cp_r(src_folder,tgt_folder,rm_dest_on_conflict=DlNGu)
+   cp_r(src_folder,tgt_folder,rm_dest_on_conflict=SMJmd)
   self.restart_container()
  def client(self):
   client,path=get_transport_and_path_from_url(self.pod_config.get("url"))
   return client,path
  def local_repo(self):
-  self.clone_dir=DlNGI(self,"clone_dir",DlNGM)
+  self.clone_dir=SMJmQ(self,"clone_dir",SMJmg)
   if not self.clone_dir:
    pod_dir_name=re.sub(r"(\s|/)+","",self.pod_name)
    self.clone_dir=os.path.join(config.TMP_FOLDER,"pods",pod_dir_name,"repo")
@@ -220,58 +220,58 @@ class CloudPodManagerGit(CloudPodManager):
  def get_pod_size(self):
   self.local_repo()
   return disk_usage(self.clone_dir)
-class PodConfigManagerMeta(DlNGo):
+class PodConfigManagerMeta(SMJmy):
  def __getattr__(cls,attr):
   def _call(*args,**kwargs):
-   result=DlNGM
+   result=SMJmg
    for manager in cls.CHAIN:
     try:
-     tmp=DlNGI(manager,attr)(*args,**kwargs)
+     tmp=SMJmQ(manager,attr)(*args,**kwargs)
      if tmp:
       if not result:
        result=tmp
-      elif DlNGm(tmp,DlNGv)and DlNGm(result,DlNGv):
+      elif SMJmj(tmp,SMJma)and SMJmj(result,SMJma):
        result.extend(tmp)
-    except DlNGd:
+    except SMJmb:
      pass
-   if result is not DlNGM:
+   if result is not SMJmg:
     return result
-   raise DlNGd('Unable to run operation "%s" for local or remote configuration'%attr)
+   raise SMJmb('Unable to run operation "%s" for local or remote configuration'%attr)
   return _call
-class PodConfigManager(DlNGp,metaclass=PodConfigManagerMeta):
+class PodConfigManager(SMJmx,metaclass=PodConfigManagerMeta):
  CHAIN=[]
- @DlNGY
+ @SMJmn
  def pod_config(cls,pod_name):
   pods=PodConfigManager.list_pods()
   pod_config=[pod for pod in pods if pod["pod_name"]==pod_name]
   if not pod_config:
-   raise DlNGd('Unable to find config for pod named "%s"'%pod_name)
+   raise SMJmb('Unable to find config for pod named "%s"'%pod_name)
   return pod_config[0]
-class PodConfigManagerLocal(DlNGp):
+class PodConfigManagerLocal(SMJmx):
  CONFIG_FILE=".localstack.yml"
  def list_pods(self):
-  local_pods=self._load_config(safe=DlNGu).get("pods",{})
+  local_pods=self._load_config(safe=SMJmd).get("pods",{})
   local_pods=[{"pod_name":k,"state":"Local Only",**v}for k,v in local_pods.items()]
-  existing_names=DlNGP([pod["pod_name"]for pod in local_pods])
+  existing_names=SMJmW([pod["pod_name"]for pod in local_pods])
   result=[pod for pod in local_pods if pod["pod_name"]not in existing_names]
   return result
  def store_pod_metadata(self,pod_name,metadata):
   pass
- def _load_config(self,safe=DlNGJ):
+ def _load_config(self,safe=SMJmf):
   try:
    return yaml.load(to_str(load_file(self.CONFIG_FILE)))
-  except DlNGd:
+  except SMJmb:
    if safe:
     return{}
-   raise DlNGd('Unable to find and parse config file "%s"'%self.CONFIG_FILE)
-class PodConfigManagerRemote(DlNGp):
+   raise SMJmb('Unable to find and parse config file "%s"'%self.CONFIG_FILE)
+class PodConfigManagerRemote(SMJmx):
  def list_pods(self):
   result=[]
   auth_headers=get_auth_headers()
   response=safe_requests.get("%s/cloudpods"%API_ENDPOINT,headers=auth_headers)
   content=response.content
   if response.status_code>=400:
-   raise DlNGd("Unable to fetch list of pods from API (code %s): %s"%(response.status_code,content))
+   raise SMJmb("Unable to fetch list of pods from API (code %s): %s"%(response.status_code,content))
   remote_pods=json.loads(to_str(content)).get("cloudpods",[])
   remote_pods=[{"state":"Shared",**pod}for pod in remote_pods]
   result.extend(remote_pods)
@@ -282,7 +282,7 @@ class PodConfigManagerRemote(DlNGp):
   response=safe_requests.post("%s/cloudpods"%API_ENDPOINT,json.dumps(metadata),headers=auth_headers)
   content=response.content
   if response.status_code>=400:
-   raise DlNGd("Unable to store pod metadata in API (code %s): %s"%(response.status_code,content))
+   raise SMJmb("Unable to store pod metadata in API (code %s): %s"%(response.status_code,content))
   return json.loads(to_str(content))
 PodConfigManager.CHAIN.append(PodConfigManagerLocal())
 PodConfigManager.CHAIN.append(PodConfigManagerRemote())
@@ -294,7 +294,7 @@ def push_state(pod_name,args):
  backend.push()
 def pull_state(pod_name,args):
  if not pod_name:
-  raise DlNGd("Need to specify a pod name")
+  raise SMJmb("Need to specify a pod name")
  backend=CloudPodManager.get(pod_name=pod_name)
  backend.pull()
 def list_pods(args):
