@@ -1,11 +1,11 @@
 import logging
-FUirH=Exception
-FUirL=any
-FUiry=str
-FUirB=None
-FUirg=False
-FUirq=bool
-FUirA=True
+NKjmr=Exception
+NKjmc=any
+NKjmM=str
+NKjmA=None
+NKjmX=False
+NKjml=bool
+NKjmy=True
 import os
 from localstack import config as localstack_config
 from localstack.constants import LOCALSTACK_INFRA_PROCESS,LOCALSTACK_WEB_PROCESS,TRUE_STRINGS
@@ -29,14 +29,14 @@ def register_localstack_plugins():
   try:
    from localstack_ext.services import dns_server
    dns_server.setup_network_configuration()
-  except FUirH:
+  except NKjmr:
    return
   if is_infra_process:
    load_plugin_files()
   try:
    if is_api_key_configured and not is_infra_process and is_api_enabled("ec2"):
     local_daemon.start_in_background()
-  except FUirH as e:
+  except NKjmr as e:
    LOG.warning("Unable to start local daemon process: %s"%e)
   if is_api_key_configured:
    if os.environ.get("EDGE_PORT")and not localstack_config.EDGE_PORT_HTTP:
@@ -67,7 +67,7 @@ def register_localstack_plugins():
    docker_flags+=["-p {a}:{p}:{p}".format(a=config_ext.DNS_ADDRESS,p=dns_server.DNS_PORT)]
   if not common.is_port_open(dns_server.DNS_PORT,protocols="udp"):
    docker_flags+=["-p {a}:{p}:{p}/udp".format(a=config_ext.DNS_ADDRESS,p=dns_server.DNS_PORT)]
- if FUirL([is_api_enabled(api)for api in EXTERNAL_PORT_APIS]):
+ if NKjmc([is_api_enabled(api)for api in EXTERNAL_PORT_APIS]):
   docker_flags+=["-p {start}-{end}:{start}-{end}".format(start=config_ext.SERVICE_INSTANCES_PORTS_START,end=config_ext.SERVICE_INSTANCES_PORTS_END)]
  if is_api_enabled("eks"):
   kube_config=os.path.expanduser("~/.kube/config")
@@ -201,24 +201,24 @@ def load_plugin_files():
   aws_utils.patch_aws_stack()
   edge.patch_start_edge()
   patch_start_infra()
- except FUirH as e:
-  if "No module named" not in FUiry(e):
+ except NKjmr as e:
+  if "No module named" not in NKjmM(e):
    print("ERROR: %s"%e)
 def patch_start_infra():
  from localstack.services import infra
  try:
   from localstack_ext.utils.aws.metadata_service import start_metadata_service
- except FUirH:
-  start_metadata_service=FUirB
+ except NKjmr:
+  start_metadata_service=NKjmA
  def do_start_infra(asynchronous,apis,is_in_docker,*args,**kwargs):
   if common.in_docker():
    try:
     start_metadata_service and start_metadata_service()
-   except FUirH:
+   except NKjmr:
     pass
   enforce_before=config_ext.ENFORCE_IAM
   try:
-   config_ext.ENFORCE_IAM=FUirg
+   config_ext.ENFORCE_IAM=NKjmX
    return do_start_infra_orig(asynchronous,apis,is_in_docker,*args,**kwargs)
   finally:
    config_ext.ENFORCE_IAM=enforce_before
@@ -241,9 +241,9 @@ def _setup_logging():
  logging.getLogger("root").setLevel(logging.WARNING)
  logging.getLogger("").setLevel(logging.WARNING)
 def api_key_configured():
- return FUirq(os.environ.get("LOCALSTACK_API_KEY"))
+ return NKjml(os.environ.get("LOCALSTACK_API_KEY"))
 def register_localstack_commands():
  if api_key_configured():
   cli.register_commands()
- return FUirA
+ return NKjmy
 # Created by pyminifier (https://github.com/liftoff/pyminifier)
